@@ -6,6 +6,7 @@ from collections import defaultdict
 
 import selenium
 from selenium import webdriver
+from selenium.webdriver.common.by import By
 from selenium.webdriver.firefox.options import Options as FirefoxOptions
 from selenium.webdriver.chrome.options import Options as ChromeOptions
 
@@ -109,7 +110,7 @@ def fetch_google_image_urls(
         scroll_to_end(driver)
 
         # get all image thumbnail results
-        thumbnail_results = driver.find_elements_by_css_selector("img.Q4LuWd")
+        thumbnail_results = driver.find_elements(By.CSS_SELECTOR, "img.Q4LuWd")
         number_results = len(thumbnail_results)
 
         log.debug(
@@ -131,7 +132,7 @@ def fetch_google_image_urls(
             # extract image urls
             try:
                 actual_image = pick_best_actual_image(
-                    driver.find_elements_by_css_selector("img.n3VNCb")
+                    driver.find_elements(By.CSS_SELECTOR, "img.n3VNCb")
                 )
             except NoImagesInWebElementError as exc:
                 log.debug("skipping empty element")
@@ -148,7 +149,7 @@ def fetch_google_image_urls(
 
             if track_related:
                 related_images = list()
-                for related_section in driver.find_elements_by_css_selector(
+                for related_section in driver.find_elements(By.CSS_SELECTOR, 
                     "div.EVPn8e"
                 ):
                     for related_image in related_section.find_elements_by_tag_name(
@@ -175,30 +176,42 @@ def fetch_google_image_urls(
 
             scroll_to_end(driver)
 
-            # look for the More Results or Load More Anyway button, preferring the latter as it is conditional
+            # look for the More Results or Load More Anyway or Cookie Accept button
             try:
-                see_more_anyway_button = driver.find_element_by_css_selector(".r0zKGf")
+                see_more_anyway_button = driver.find_element(By.CSS_SELECTOR, ".r0zKGf")
             except selenium.common.exceptions.NoSuchElementException:
                 see_more_anyway_button = None
 
             try:
                 # Show More Results
-                load_more_button = driver.find_element_by_css_selector(".mye4qd")
+                load_more_button = driver.find_element(By.CSS_SELECTOR, ".mye4qd")
             except selenium.common.exceptions.NoSuchElementException:
                 load_more_button = None
 
+            try:
+                # Accept cookies
+                accept_cookies_button = driver.find_element(
+                    By.XPATH, "//button[@jsname = 'b3VHJd']"
+                )
+            except selenium.common.exceptions.NoSuchElementException:
+                accept_cookies_button = None
+
             if see_more_anyway_button:
                 # prefer the see more anyway button
                 try:
-                    driver.execute_script("document.querySelector('.r0zKGf').click();")
+                    see_more_anyway_button.click()
                     log.debug("clicked See More Anyway")
                     random_sleep(sleep_between_interactions)
                 except selenium.common.exceptions.NoSuchElementException:
                     pass
             elif load_more_button:
-                driver.execute_script("document.querySelector('.mye4qd').click();")
+                load_bore_button.click()
                 log.debug("clicked More Results")
                 random_sleep(sleep_between_interactions * 10)
+            elif accept_cookies_button:
+                accept_cookies_button.click()
+                log.debug("accepted cookies")
+                random_sleep(sleep_between_interactions * 10)
             else:
                 log.debug(driver.page_source)
                 log.warning(f"No path for more images found")
